<?php
namespace Ep\Woo;

use Ep\Config\ConfigAggregator;
use Zend\ConfigAggregator\ArrayProvider;
use Zend\ConfigAggregator\PhpFileProvider;
use Zend\ServiceManager\AbstractFactory\ReflectionBasedAbstractFactory;
use Zend\ServiceManager\Factory\InvokableFactory;

/**
 * Class ConfigProvider
 *
 * @package Ep\Woo
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class ConfigProvider
{
    /**
     * Vraća konfiguraciju.
     *
     * @return array
     */
    public function __invoke()
    {
        return (new ConfigAggregator([
            new PhpFileProvider(__DIR__ . '/../config/*.config.php'),

            new ArrayProvider([
                'dependencies' => [
                    'factories' => [
                        View\TwigExtension::class => InvokableFactory::class,
                    ],
                ],

                'twig' => [
                    'template_paths' => [
                        'woo' => [
                            dirname(__DIR__) . '/view',
                        ],
                    ],

                    'extensions' => [
                        View\TwigExtension::class,
                    ],
                ],

                'wp_widgets' => [
                    'aliases' => [
                        'woo.categories' => Widget\Categories::class,
                    ],

                    'factories' => [
                        Widget\Categories::class => InvokableFactory::class,
                    ],
                ],

                'wp' => [
                    'widgets' => [
                        'woo.categories',
                    ],
                ],
            ]),
        ]))->getMergedConfig();
    }
}