<?php
namespace Ep\Woo\Form\View\Element;

use Ep\Woo\View\AbstractView;
use Psr\Container\ContainerInterface;
use Twig_Environment;
use Zend\View\Helper\HelperInterface;
use Zend\View\HelperPluginManager;

/**
 * Class Quantity
 *
 * @package Ep\Woo\Form\View\Element
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class Quantity extends AbstractView
{
    /** @var array */
    protected $templateOverrides = [
        'global/quantity-input.php',
    ];

    /** @var HelperPluginManager */
    private $helpers;

    /**
     * Quantity constructor.
     *
     * @param Twig_Environment $twig
     */
    public function __construct(Twig_Environment $twig, ContainerInterface $container)
    {
        parent::__construct($twig);

        $this->helpers = $container->get(HelperPluginManager::class);
    }

    /**
     * Renderira view.
     *
     * @return string
     *
     * @throws \Twig_Error_Loader
     * @throws \Twig_Error_Runtime
     * @throws \Twig_Error_Syntax
     */
    public function render(): string
    {
        $args = func_get_args()[3];

        $element = new \Ep\Woo\Form\Element\Quantity($args['input_name'], [
            'label' => __('Quantity', 'woocommerce'),
        ]);

        $element->init();

        $element->setAttributes([
            'id' => $args['input_id'],
            'value' => $args['input_value'],
            'min' => $args['min_value'],
            'max' => $args['max_value'],
            'step' => $args['step'],
            'pattern' => $args['pattern'],
            'inputmode' => 'numeric',
        ]);

        $helper = $this->helpers->get('form_quantity');

        return $helper($element);
    }
}